diff --git a/bob/bio/face/extractor/DCTBlocks.py b/bob/bio/face/extractor/DCTBlocks.py
index ea9bf6c8b8516008c432a86602fc339a83b0726c..614bde5588687ac56229e968f9362836fcd56a98 100644
--- a/bob/bio/face/extractor/DCTBlocks.py
+++ b/bob/bio/face/extractor/DCTBlocks.py
@@ -13,7 +13,7 @@ class DCTBlocks (Extractor):
 
   """Extracts *Discrete Cosine Transform* (DCT) features from (overlapping) image blocks.
   These features are based on the :py:class:`bob.ip.base.DCTFeatures` class.
-  The default parametrization is the one that performed best on the BANCA database in [WMM+11]_.
+  The default parametrization is the one that performed best on the BANCA database in [WMM11]_.
 
   Usually, these features are used in combination with the algorithms defined in :ref:`bob.bio.gmm <bob.bio.gmm>`.
   However, you can try to use them with other algorithms.
diff --git a/doc/baselines.rst b/doc/baselines.rst
index 74117f56e578638bc5a832f88a8928109f5e3be3..3f60912f0fcd1f03b9a2bb3d1163402f37f24924 100644
--- a/doc/baselines.rst
+++ b/doc/baselines.rst
@@ -72,7 +72,7 @@ The algorithms present an (incomplete) set of state-of-the-art face recognition
   - feature : :py:class:`bob.bio.base.extractor.Linearize`
   - algorithm : :py:class:`bob.bio.base.algorithm.PCA`
 
-* ``lda``: The LDA algorithm applies a *Linear Discriminant Analysis* (LDA), here we use the combined PCA+LDA approach [ZKC+98]_:
+* ``lda``: The LDA algorithm applies a *Linear Discriminant Analysis* (LDA), here we use the combined PCA+LDA approach [ZKC98]_:
 
   - preprocessor : :py:class:`bob.bio.face.preprocessor.FaceCrop`
   - feature : :py:class:`bob.bio.face.extractor.Eigenface`
@@ -85,7 +85,7 @@ The algorithms present an (incomplete) set of state-of-the-art face recognition
   - algorithm : :py:class:`bob.bio.face.algorithm.GaborJet`
 
 
-* ``plda``: *Probabilistic LDA* (PLDA) [Pri07]_ is a probabilistic generative version of the LDA, in its scalable formulation of [ESM+13]_.
+* ``plda``: *Probabilistic LDA* (PLDA) [Pri07]_ is a probabilistic generative version of the LDA, in its scalable formulation of [ESM13]_.
   Here, we also apply it on pixel-based representations of the image, though also other features should be possible.
 
   - preprocessor : :py:class:`bob.bio.face.preprocessor.FaceCrop`
@@ -110,7 +110,7 @@ Further algorithms are available, when the :ref:`bob.bio.gmm <bob.bio.gmm>` pack
   - feature : :py:class:`bob.bio.face.extractor.DCTBlocks`
   - algorithm : :py:class:`bob.bio.gmm.algorithm.GMM`
 
-* ``isv``: As an extension of the GMM algorithm, *Inter-Session Variability* (ISV) modeling [WMM+11]_ is used to learn what variations in images are introduced by identity changes and which not.
+* ``isv``: As an extension of the GMM algorithm, *Inter-Session Variability* (ISV) modeling [WMM11]_ is used to learn what variations in images are introduced by identity changes and which not.
 
   - preprocessor : :py:class:`bob.bio.face.preprocessor.TanTriggs`
   - feature : :py:class:`bob.bio.face.extractor.DCTBlocks`
@@ -128,13 +128,13 @@ Further algorithms are available, when the :ref:`bob.bio.gmm <bob.bio.gmm>` pack
 
 Additionally, the following algorithms can be executed, when the :ref:`bob.bio.csu <bob.bio.csu>` package is installed.
 
-* ``lrpca``: In Local Region PCA [PBD+11]_, the face is sub-divided into local regions and a PCA is performed for each local region.
+* ``lrpca``: In Local Region PCA [PBD11]_, the face is sub-divided into local regions and a PCA is performed for each local region.
 
   - preprocessor : :py:class:`bob.bio.csu.preprocessor.LRPCA`
   - feature : :py:class:`bob.bio.csu.extractor.LRPCA`
   - algorithm : :py:class:`bob.bio.csu.algorithm.LRPCA`
 
-* ``lda-ir``: The LDA-IR (a.k.a. CohortLDA [LBP+12]_) extracts color information from images after, and computes a PCA+LDA projection on two color layers.
+* ``lda-ir``: The LDA-IR (a.k.a. CohortLDA [LBP12]_) extracts color information from images after, and computes a PCA+LDA projection on two color layers.
 
   - preprocessor : :py:class:`bob.bio.csu.preprocessor.LDAIR`
   - feature : :py:class:`bob.bio.csu.extractor.LDAIR`
diff --git a/doc/references.rst b/doc/references.rst
index b8187f3c9b19878856fb0e378e1baeb1c6b27e26..c1cfb2c8065d144dcb8318475cd38b503abbb989 100644
--- a/doc/references.rst
+++ b/doc/references.rst
@@ -7,26 +7,22 @@ References
 ==========
 
 .. [TP91]    *M. Turk and A. Pentland*. **Eigenfaces for recognition**. Journal of Cognitive Neuroscience, 3(1):71-86, 1991.
-.. [ZKC+98]  *W. Zhao, A. Krishnaswamy, R. Chellappa, D. Swets and J. Weng*. **Discriminant analysis of principal components for face recognition**, pages 73-85. Springer Verlag Berlin, 1998.
+.. [ZKC98]  *W. Zhao, A. Krishnaswamy, R. Chellappa, D. Swets and J. Weng*. **Discriminant analysis of principal components for face recognition**, pages 73-85. Springer Verlag Berlin, 1998.
 .. [MWP98]   *B. Moghaddam, W. Wahid and A. Pentland*. **Beyond eigenfaces: probabilistic matching for face recognition**. IEEE International Conference on Automatic Face and Gesture Recognition, pages 30-35. 1998.
-.. [PBD+11]  *P.J. Phillips, J.R. Beveridge, B.A. Draper, G. Givens, A.J. O'Toole, D.S. Bolme, J. Dunlop, Y.M. Lui, H. Sahibzada and S. Weimer*. **An introduction to the good, the bad, & the ugly face recognition challenge problem**. Automatic face gesture recognition and workshops (FG 2011), pages 346-353. 2011.
-.. [LBP+12]  *Y.M. Lui, D. Bolme, P.J. Phillips, J.R. Beveridge and B.A. Draper*. **Preliminary studies on the good, the bad, and the ugly face recognition challenge problem**. Computer vision and pattern recognition workshops (CVPRW), pages 9-16. 2012.
+.. [PBD11]  *P.J. Phillips, J.R. Beveridge, B.A. Draper, G. Givens, A.J. O'Toole, D.S. Bolme, J. Dunlop, Y.M. Lui, H. Sahibzada and S. Weimer*. **An introduction to the good, the bad, & the ugly face recognition challenge problem**. Automatic face gesture recognition and workshops (FG 2011), pages 346-353. 2011.
+.. [LBP12]  *Y.M. Lui, D. Bolme, P.J. Phillips, J.R. Beveridge and B.A. Draper*. **Preliminary studies on the good, the bad, and the ugly face recognition challenge problem**. Computer vision and pattern recognition workshops (CVPRW), pages 9-16. 2012.
 .. [GHW12]   *M. Günther, D. Haufe and R.P. Würtz*. **Face recognition with disparity corrected Gabor phase differences**. In Artificial neural networks and machine learning, volume 7552 of Lecture Notes in Computer Science, pages 411-418. 9/2012.
-.. [ZSG+05]  *W. Zhang, S. Shan, W. Gao, X. Chen and H. Zhang*. **Local Gabor binary pattern histogram sequence (LGBPHS): a novel non-statistical model for face representation and recognition**. Computer Vision, IEEE International Conference on, 1:786-791, 2005.
+.. [ZSG05]  *W. Zhang, S. Shan, W. Gao, X. Chen and H. Zhang*. **Local Gabor binary pattern histogram sequence (LGBPHS): a novel non-statistical model for face representation and recognition**. Computer Vision, IEEE International Conference on, 1:786-791, 2005.
 .. [MM09]    *C. McCool, S. Marcel*. **Parts-based face verification using local frequency bands**. In Advances in biometrics, volume 5558 of Lecture Notes in Computer Science. 2009.
-.. [WMM+12]  *R. Wallace, M. McLaren, C. McCool and S. Marcel*. **Cross-pollination of normalisation techniques from speaker to face authentication using Gaussian mixture models**. IEEE Transactions on Information Forensics and Security, 2012.
-.. [WMM+11]  *R. Wallace, M. McLaren, C. McCool and S. Marcel*. **Inter-session variability modelling and joint factor analysis for face authentication**. International Joint Conference on Biometrics. 2011.
+.. .. [WMM12]  *R. Wallace, M. McLaren, C. McCool and S. Marcel*. **Cross-pollination of normalisation techniques from speaker to face authentication using Gaussian mixture models**. IEEE Transactions on Information Forensics and Security, 2012.
+.. [WMM11]  *R. Wallace, M. McLaren, C. McCool and S. Marcel*. **Inter-session variability modelling and joint factor analysis for face authentication**. International Joint Conference on Biometrics. 2011.
 .. [Pri07]   *S. J. D. Prince*. **Probabilistic linear discriminant analysis for inferences about identity**. Proceedings of the International Conference on Computer Vision. 2007.
-.. [ESM+13]  *L. El Shafey, Chris McCool, Roy Wallace and Sébastien Marcel*. **A scalable formulation of probabilistic linear discriminant analysis: applied to face recognition**. IEEE Transactions on Pattern Analysis and Machine Intelligence, 35(7):1788-1794, 7/2013.
-
+.. [ESM13]  *L. El Shafey, Chris McCool, Roy Wallace and Sébastien Marcel*. **A scalable formulation of probabilistic linear discriminant analysis: applied to face recognition**. IEEE Transactions on Pattern Analysis and Machine Intelligence, 35(7):1788-1794, 7/2013.
 .. [WM12]    *R. Wallace and M. McLaren*. **Total variability modelling for face verification**. IET Biometrics, vol.1, no.4, 188-199, 12/2012
-
 .. [TT10]    *X. Tan and B. Triggs*. **Enhanced local texture feature sets for face recognition under difficult lighting conditions**. IEEE Transactions on Image Processing, 19(6):1635-1650, 2010.
 .. [WLW04]   *H. Wang, S.Z. Li and Y. Wang*. **Face recognition under varying lighting conditions using self quotient image**. In IEEE International Conference on Automatic Face and Gesture Recognition (AFGR), pages 819-824. 2004.
-.. [HRM06]   *G. Heusch, Y. Rodriguez, and S. Marcel*. **Local Binary Patterns as an Image Preprocessing for Face Authentication**. In IEEE International Conference on Automatic Face and Gesture Recognition (AFGR), 2006.
-
+.. .. [HRM06]   *G. Heusch, Y. Rodriguez, and S. Marcel*. **Local Binary Patterns as an Image Preprocessing for Face Authentication**. In IEEE International Conference on Automatic Face and Gesture Recognition (AFGR), 2006.
 .. [WFK97]   *L. Wiskott, J.-M. Fellous, N. Krüger and C.v.d. Malsburg*. **Face recognition by elastic bunch graph matching**. IEEE Transactions on Pattern Analysis and Machine Intelligence, 19:775-779, 1997.
-.. [ZSQ+09]  *W. Zhang, S. Shan, L. Qing, X. Chen and W. Gao*. **Are Gabor phases really useless for face recognition?** Pattern Analysis & Applications, 12:301-307, 2009.
+.. [ZSQ09]  *W. Zhang, S. Shan, L. Qing, X. Chen and W. Gao*. **Are Gabor phases really useless for face recognition?** Pattern Analysis & Applications, 12:301-307, 2009.
 .. [GW09]    *M. Günther and R.P. Würtz*. **Face detection and recognition using maximum likelihood classifiers on Gabor graphs**. International Journal of Pattern Recognition and Artificial Intelligence, 23(3):433-461, 2009.
-
-.. [GWM12]   *M. Günther, R. Wallace and S. Marcel*. **An Open Source Framework for Standardized Comparisons of Face Recognition Algorithms**. Computer Vision - ECCV 2012. Workshops and Demonstrations, LNCS, 7585, 547-556, 2012.
+.. .. [GWM12]   *M. Günther, R. Wallace and S. Marcel*. **An Open Source Framework for Standardized Comparisons of Face Recognition Algorithms**. Computer Vision - ECCV 2012. Workshops and Demonstrations, LNCS, 7585, 547-556, 2012.
diff --git a/bob/bio/face/extractor/LGBPHS.py b/bob/bio/face/extractor/LGBPHS.py
index bc4ec3c3cfa4bbd85eb7e8ff6dea8620e86e4e1e..7f18fd8f4bf224cf6bcc8ae6c6b30e4987cb4fdc 100644
--- a/bob/bio/face/extractor/LGBPHS.py
+++ b/bob/bio/face/extractor/LGBPHS.py
@@ -11,7 +11,7 @@ import math
 from bob.bio.base.extractor import Extractor
 
 class LGBPHS (Extractor):
   """Extracts *Local Gabor Binary Pattern Histogram Sequences* (LGBPHS) [ZSG+05]_ from the images, using functionality from :ref:`bob.ip.base <bob.ip.base>` and :ref:`bob.ip.gabor <bob.ip.gabor>`.
 
   The block size and the overlap of the blocks can be varied, as well as the parameters of the Gabor wavelet (:py:class:`bob.ip.gabor.Transform`) and the LBP extractor (:py:class:`bob.ip.base.LBP`).
 
@@ -32,14 +32,14 @@ class LGBPHS (Extractor):
 
   use_gabor_phases : bool
     Extract also the Gabor phases (inline) and not only the absolute values.
-    In this case, Extended LGBPHS features [ZSQ+09]_ will be extracted.
+    In this case, Extended LGBPHS features [ZSQ09]_ will be extracted.
 
   lbp_radius, lbp_neighbor_count, lbp_uniform, lbp_circular, lbp_rotation_invariant, lbp_compare_to_average, lbp_add_average
     The parameters of the LBP.
     Please see :py:class:`bob.ip.base.LBP` for the documentation of these values.
 
     .. note::
-       The default values are as given in [ZSG+05]_ (the values of [ZSQ+09]_ might differ).
+       The default values are as given in [ZSG05]_ (the values of [ZSQ09]_ might differ).
 
   sparse_histogram : bool
     If specified, the histograms will be handled in a sparse way.
@@ -11,7 +11,7 @@ import math
 
 class LGBPHS (Extractor):
-  """Extracts *Local Gabor Binary Pattern Histogram Sequences* (LGBPHS) [ZSG+05]_ from the images, using functionality from :ref:`bob.ip.base <bob.ip.base>` and :ref:`bob.ip.gabor <bob.ip.gabor>`.
+  """Extracts *Local Gabor Binary Pattern Histogram Sequences* (LGBPHS) [ZSG05]_ from the images, using functionality from :ref:`bob.ip.base <bob.ip.base>` and :ref:`bob.ip.gabor <bob.ip.gabor>`.
 
   The block size and the overlap of the blocks can be varied, as well as the parameters of the Gabor wavelet (:py:class:`bob.ip.gabor.Transform`) and the LBP extractor (:py:class:`bob.ip.base.LBP`).